"use strict";

var _logger = require("@linaria/logger");
var _BaseEntrypoint = require("../BaseEntrypoint");
describe('createExports', () => {
  it('should be defined', () => {
    expect(_BaseEntrypoint.createExports).toBeDefined();
  });
  it('should create exports object', () => {
    const exports = (0, _BaseEntrypoint.createExports)(_logger.linariaLogger);
    expect(exports).toBeDefined();
  });
  it('should set and get value', () => {
    const exports = (0, _BaseEntrypoint.createExports)(_logger.linariaLogger);
    exports.foo = 'bar';
    expect(exports.foo).toBe('bar');
  });
  it('should set and get value with defineProperty', () => {
    const exports = (0, _BaseEntrypoint.createExports)(_logger.linariaLogger);
    Object.defineProperty(exports, 'foo', {
      value: 'bar'
    });
    expect(exports.foo).toBe('bar');
  });
  it('should set and get value with defineProperty and getter', () => {
    const exports = (0, _BaseEntrypoint.createExports)(_logger.linariaLogger);
    Object.defineProperty(exports, 'foo', {
      get: () => 'bar'
    });
    expect(exports.foo).toBe('bar');
  });
  it('should not override value with undefined', () => {
    const exports = (0, _BaseEntrypoint.createExports)(_logger.linariaLogger);
    exports.foo = 'bar';
    exports.foo = undefined;
    expect(exports.foo).toBe('bar');
  });
  it('should not override value with defineProperty and undefined', () => {
    const exports = (0, _BaseEntrypoint.createExports)(_logger.linariaLogger);
    exports.foo = 'bar';
    Object.defineProperty(exports, 'foo', {
      value: undefined
    });
    expect(exports.foo).toBe('bar');
  });
  it('should not override value with defineProperty and getter returning undefined', () => {
    const exports = (0, _BaseEntrypoint.createExports)(_logger.linariaLogger);
    exports.foo = 'bar';
    Object.defineProperty(exports, 'foo', {
      get: () => undefined
    });
    expect(exports.foo).toBe('bar');
  });
  it('should not override lazy value with defineProperty and getter returning undefined', () => {
    const exports = (0, _BaseEntrypoint.createExports)(_logger.linariaLogger);
    Object.defineProperty(exports, 'foo', {
      get: () => 'bar'
    });
    Object.defineProperty(exports, 'foo', {
      get: () => undefined
    });
    expect(exports.foo).toBe('bar');
  });
});
//# sourceMappingURL=createExports.test.js.map