/**
 * This file exposes transform function that:
 * - parse the passed code to AST
 * - transforms the AST using Linaria babel preset ('./babel/index.js) and additional config defined in Linaria config file or passed to bundler configuration.
 * - runs generated CSS files through default of user-defined preprocessor
 * - generates source maps for CSS files
 * - return transformed code (without Linaria template literals), generated CSS, source maps and babel metadata from transform step.
 */
import type { PartialOptions } from './transform/helpers/loadLinariaOptions';
import type { Handlers, Services } from './transform/types';
import type { Result } from './types';
type PartialServices = Partial<Omit<Services, 'options'>> & {
    options: Omit<Services['options'], 'pluginOptions'> & {
        pluginOptions?: PartialOptions;
    };
};
type AllHandlers<TMode extends 'async' | 'sync'> = Handlers<TMode>;
export declare function transformSync(partialServices: PartialServices, originalCode: string, syncResolve: (what: string, importer: string, stack: string[]) => string, customHandlers?: Partial<AllHandlers<'sync'>>): Result;
export default function transform(partialServices: PartialServices, originalCode: string, asyncResolve: (what: string, importer: string, stack: string[]) => Promise<string | null>, customHandlers?: Partial<AllHandlers<'sync'>>): Promise<Result>;
export {};
